﻿using System;
using System.Collections.Generic;
using RocketGMPurchase.Models;

namespace RocketGMPurchase.Helpers
{
    public static class PriceHelper
    {
        private static Dictionary<RocGmCurrencyCode, string> CurrencyIconBy =
            new Dictionary<RocGmCurrencyCode, string>()
            {
                { RocGmCurrencyCode.AED, "د.إ" }, // United Arab Emirates Dirham   -----  Unsupported Character -------
                { RocGmCurrencyCode.AFN, "؋" }, // Afghan Afghani     -----  Unsupported Character -------
                { RocGmCurrencyCode.ALL, "L" }, // Albanian Lek
                { RocGmCurrencyCode.AMD, "֏" }, // Armenian Dram      -----  Unsupported Character -------
                { RocGmCurrencyCode.ANG, "ƒ" }, // Netherlands Antillean Guilder
                { RocGmCurrencyCode.AOA, "Kz" }, // Angolan Kwanza
                { RocGmCurrencyCode.ARS, "$" }, // Argentine Peso
                { RocGmCurrencyCode.AUD, "$" }, // Australian Dollar
                { RocGmCurrencyCode.AWG, "ƒ" }, // Aruban Florin
                { RocGmCurrencyCode.AZN, "₼" }, // Azerbaijani Manat
                { RocGmCurrencyCode.BAM, "KM" }, // Bosnia and Herzegovina Convertible Mark
                { RocGmCurrencyCode.BBD, "$" }, // Barbadian Dollar
                { RocGmCurrencyCode.BDT, "৳" }, // Bangladeshi Taka     -----  Unsupported Character -------
                { RocGmCurrencyCode.BGN, "лв" }, // Bulgarian Lev
                { RocGmCurrencyCode.BHD, ".د.ب" }, // Bahraini Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.BIF, "Fr" }, // Burundian Franc
                { RocGmCurrencyCode.BMD, "$" }, // Bermudian Dollar
                { RocGmCurrencyCode.BND, "$" }, // Brunei Dollar
                { RocGmCurrencyCode.BOB, "Bs." }, // Bolivian Boliviano
                { RocGmCurrencyCode.BRL, "R$" }, // Brazilian Real
                { RocGmCurrencyCode.BSD, "$" }, // Bahamian Dollar
                { RocGmCurrencyCode.BTN, "Nu." }, // Bhutanese Ngultrum
                { RocGmCurrencyCode.BWP, "P" }, // Botswana Pula
                { RocGmCurrencyCode.BYN, "Br" }, // Belarusian Ruble
                { RocGmCurrencyCode.BZD, "BZ$" }, // Belize Dollar
                { RocGmCurrencyCode.CAD, "$" }, // Canadian Dollar
                { RocGmCurrencyCode.CDF, "Fr" }, // Congolese Franc
                { RocGmCurrencyCode.CHF, "Fr." }, // Swiss Franc
                { RocGmCurrencyCode.CLP, "$" }, // Chilean Peso
                { RocGmCurrencyCode.CNY, "¥" }, // Chinese Yuan
                { RocGmCurrencyCode.COP, "$" }, // Colombian Peso
                { RocGmCurrencyCode.CRC, "₡" }, // Costa Rican Colón
                { RocGmCurrencyCode.CUP, "$MN" }, // Cuban Peso
                { RocGmCurrencyCode.CVE, "$" }, // Cape Verdean Escudo
                { RocGmCurrencyCode.CZK, "Kč" }, // Czech Republic Koruna
                { RocGmCurrencyCode.DJF, "Fr" }, // Djiboutian Franc
                { RocGmCurrencyCode.DKK, "kr" }, // Danish Krone
                { RocGmCurrencyCode.DOP, "$" }, // Dominican Peso
                { RocGmCurrencyCode.DZD, "د.ج" }, // Algerian Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.EGP, "£" }, // Egyptian Pound
                { RocGmCurrencyCode.ERN, "Nfk" }, // Eritrean Nakfa
                { RocGmCurrencyCode.ETB, "Br" }, // Ethiopian Birr
                { RocGmCurrencyCode.EUR, "€" }, // Euro
                { RocGmCurrencyCode.FJD, "$" }, // Fijian Dollar
                { RocGmCurrencyCode.FKP, "£" }, // Falkland Islands Pound
                { RocGmCurrencyCode.FOK, "kr" }, // Faroese Króna
                { RocGmCurrencyCode.GBP, "£" }, // British Pound Sterling
                { RocGmCurrencyCode.GEL, "₾" }, // Georgian Lari
                { RocGmCurrencyCode.GGP, "£" }, // Guernsey Pound
                { RocGmCurrencyCode.GHS, "₵" }, // Ghanaian Cedi
                { RocGmCurrencyCode.GIP, "£" }, // Gibraltar Pound
                { RocGmCurrencyCode.GMD, "D" }, // Gambian Dalasi
                { RocGmCurrencyCode.GNF, "Fr" }, // Guinean Franc
                { RocGmCurrencyCode.GTQ, "Q" }, // Guatemalan Quetzal
                { RocGmCurrencyCode.GYD, "$" }, // Guyanese Dollar
                { RocGmCurrencyCode.HKD, "$" }, // Hong Kong Dollar
                { RocGmCurrencyCode.HNL, "L" }, // Honduran Lempira
                { RocGmCurrencyCode.HRK, "kn" }, // Croatian Kuna
                { RocGmCurrencyCode.HTG, "G" }, // Haitian Gourde
                { RocGmCurrencyCode.HUF, "Ft" }, // Hungarian Forint
                { RocGmCurrencyCode.IDR, "Rp" }, // Indonesian Rupiah
                { RocGmCurrencyCode.ILS, "₪" }, // Israeli New Shekel
                { RocGmCurrencyCode.IMP, "£" }, // Isle of Man Pound
                { RocGmCurrencyCode.INR, "₹" }, // Indian Rupee
                { RocGmCurrencyCode.IQD, "ع.د" }, // Iraqi Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.IRR, "﷼" }, // Iranian Rial     -----  Unsupported Character -------
                { RocGmCurrencyCode.ISK, "kr" }, // Icelandic Króna
                { RocGmCurrencyCode.JEP, "£" }, // Jersey Pound
                { RocGmCurrencyCode.JMD, "J$" }, // Jamaican Dollar
                { RocGmCurrencyCode.JOD, "د.ا" }, // Jordanian Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.JPY, "¥" }, // Japanese Yen
                { RocGmCurrencyCode.KES, "KSh" }, // Kenyan Shilling
                { RocGmCurrencyCode.KGS, "сом" }, // Kyrgyzstani Som
                { RocGmCurrencyCode.KHR, "៛" }, // Cambodian Riel     -----  Unsupported Character -------
                { RocGmCurrencyCode.KID, "$" }, // Kiribati Dollar
                { RocGmCurrencyCode.KMF, "Fr" }, // Comorian Franc
                { RocGmCurrencyCode.KRW, "₩" }, // South Korean Won
                { RocGmCurrencyCode.KWD, "د.ك" }, // Kuwaiti Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.KYD, "$" }, // Cayman Islands Dollar
                { RocGmCurrencyCode.KZT, "₸" }, // Kazakhstani Tenge
                { RocGmCurrencyCode.LAK, "₭" }, // Lao Kip
                { RocGmCurrencyCode.LBP, "ل.ل" }, // Lebanese Pound     -----  Unsupported Character -------
                { RocGmCurrencyCode.LKR, "Rs" }, // Sri Lankan Rupee
                { RocGmCurrencyCode.LRD, "$" }, // Liberian Dollar
                { RocGmCurrencyCode.LSL, "L" }, // Lesotho Loti
                { RocGmCurrencyCode.LYD, "ل.د" }, // Libyan Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.MAD, "د.م." }, // Moroccan Dirham     -----  Unsupported Character -------
                { RocGmCurrencyCode.MDL, "L" }, // Moldovan Leu
                { RocGmCurrencyCode.MGA, "Ar" }, // Malagasy Ariary
                { RocGmCurrencyCode.MKD, "ден" }, // Macedonian Denar
                { RocGmCurrencyCode.MMK, "K" }, // Burmese Kyat
                { RocGmCurrencyCode.MNT, "₮" }, // Mongolian Tugrik
                { RocGmCurrencyCode.MOP, "P" }, // Macanese Pataca
                { RocGmCurrencyCode.MRU, "UM" }, // Mauritanian Ouguiya
                { RocGmCurrencyCode.MUR, "Rs" }, // Mauritian Rupee
                { RocGmCurrencyCode.MVR, "Rf" }, // Maldivian Rufiyaa
                { RocGmCurrencyCode.MWK, "MK" }, // Malawian Kwacha
                { RocGmCurrencyCode.MXN, "$" }, // Mexican Peso
                { RocGmCurrencyCode.MYR, "RM" }, // Malaysian Ringgit
                { RocGmCurrencyCode.MZN, "MT" }, // Mozambican Metical
                { RocGmCurrencyCode.NAD, "$" }, // Namibian Dollar
                { RocGmCurrencyCode.NGN, "₦" }, // Nigerian Naira
                { RocGmCurrencyCode.NIO, "C$" }, // Nicaraguan Córdoba
                { RocGmCurrencyCode.NOK, "kr" }, // Norwegian Krone
                { RocGmCurrencyCode.NPR, "Rs" }, // Nepalese Rupee
                { RocGmCurrencyCode.NZD, "$" }, // New Zealand Dollar
                { RocGmCurrencyCode.OMR, "ر.ع." }, // Omani Rial     -----  Unsupported Character -------
                { RocGmCurrencyCode.PAB, "B/." }, // Panamanian Balboa
                { RocGmCurrencyCode.PEN, "S/." }, // Peruvian Nuevo Sol
                { RocGmCurrencyCode.PGK, "K" }, // Papua New Guinean Kina
                { RocGmCurrencyCode.PHP, "₱" }, // Philippine Peso
                { RocGmCurrencyCode.PKR, "₨" }, // Pakistani Rupee
                { RocGmCurrencyCode.PLN, "zł" }, // Polish Złoty
                { RocGmCurrencyCode.PYG, "₲" }, // Paraguayan Guarani
                { RocGmCurrencyCode.QAR, "ر.ق" }, // Qatari Rial     -----  Unsupported Character -------
                { RocGmCurrencyCode.RON, "lei" }, // Romanian Leu
                { RocGmCurrencyCode.RSD, "дин." }, // Serbian Dinar
                { RocGmCurrencyCode.RUB, "₽" }, // Russian Ruble
                { RocGmCurrencyCode.RWF, "Fr" }, // Rwandan Franc
                { RocGmCurrencyCode.SAR, "ر.س" }, // Saudi Riyal     -----  Unsupported Character -------
                { RocGmCurrencyCode.SBD, "$" }, // Solomon Islands Dollar
                { RocGmCurrencyCode.SCR, "₨" }, // Seychellois Rupee
                { RocGmCurrencyCode.SDG, "ج.س." }, // Sudanese Pound     -----  Unsupported Character -------
                { RocGmCurrencyCode.SEK, "kr" }, // Swedish Krona
                { RocGmCurrencyCode.SGD, "$" }, // Singapore Dollar
                { RocGmCurrencyCode.SHP, "£" }, // Saint Helena Pound
                { RocGmCurrencyCode.SLL, "Le" }, // Sierra Leonean Leone
                { RocGmCurrencyCode.SOS, "Sh" }, // Somali Shilling
                { RocGmCurrencyCode.SRD, "$" }, // Surinamese Dollar
                { RocGmCurrencyCode.SSP, "£" }, // South Sudanese Pound
                { RocGmCurrencyCode.STN, "Db" }, // São Tomé and Príncipe Dobra
                { RocGmCurrencyCode.SYP, "ل.س" }, // Syrian Pound     -----  Unsupported Character -------
                { RocGmCurrencyCode.SZL, "L" }, // Swazi Lilangeni
                { RocGmCurrencyCode.THB, "฿" }, // Thai Baht     -----  Unsupported Character -------
                { RocGmCurrencyCode.TJS, "ЅМ" }, // Tajikistani Somoni
                { RocGmCurrencyCode.TMT, "m" }, // Turkmenistan Manat
                { RocGmCurrencyCode.TND, "د.ت" }, // Tunisian Dinar     -----  Unsupported Character -------
                { RocGmCurrencyCode.TOP, "T$" }, // Tongan Pa'anga
                { RocGmCurrencyCode.TRY, "₺" }, // Turkish Lira
                { RocGmCurrencyCode.TTD, "TT$" }, // Trinidad and Tobago Dollar
                { RocGmCurrencyCode.TWD, "NT$" }, // New Taiwan Dollar
                { RocGmCurrencyCode.TZS, "Sh" }, // Tanzanian Shilling
                { RocGmCurrencyCode.UAH, "₴" }, // Ukrainian Hryvnia
                { RocGmCurrencyCode.UGX, "Sh" }, // Ugandan Shilling
                { RocGmCurrencyCode.USD, "$" }, // United States Dollar
                { RocGmCurrencyCode.UYU, "$U" }, // Uruguayan Peso
                { RocGmCurrencyCode.UZS, "сўм" }, // Uzbekistani Som
                { RocGmCurrencyCode.VES, "Bs." }, // Venezuelan Bolívar
                { RocGmCurrencyCode.VEB, "Bs." }, // Venezuelan Bolívar
                { RocGmCurrencyCode.VND, "₫" }, // Vietnamese Đồng
                { RocGmCurrencyCode.VUV, "VT" }, // Vanuatu Vatu
                { RocGmCurrencyCode.WST, "WS$" }, // Samoan Tala
                { RocGmCurrencyCode.XAF, "Fr" }, // Central African CFA Franc
                { RocGmCurrencyCode.XCD, "$" }, // East Caribbean Dollar
                { RocGmCurrencyCode.XDR, "SDR" }, // Special Drawing Rights
                { RocGmCurrencyCode.XOF, "Fr" }, // West African CFA Franc
                { RocGmCurrencyCode.XPF, "Fr" }, // CFP Franc
                { RocGmCurrencyCode.YER, "﷼" }, // Yemeni Rial     -----  Unsupported Character -------
                { RocGmCurrencyCode.ZAR, "R" }, // South African Rand
                { RocGmCurrencyCode.ZMW, "ZK" }, // Zambian Kwacha
                { RocGmCurrencyCode.ZWD, "$" }, // Zimbabwean Dollar
                { RocGmCurrencyCode.ZWL, "$" }, // Zimbabwean Dollar
            };

        private const string FallbackCurrencyIcon = "$";

        public static string GetProductPriceWithCurrencyIcon(string productId)
        {
            return GetProductCurrencyIcon(productId) + RocGMPurchaseController.Instance.GetProductPrice(productId);
        }

        private static bool TryGetCurrencyIcon(string code, out string icon)
        {
            var currencyCode = Enum.TryParse<RocGmCurrencyCode>(code, out var rocGmCurrencyCode)
                ? rocGmCurrencyCode
                : RocGmCurrencyCode.USD;
            return CurrencyIconBy.TryGetValue(currencyCode, out icon);
        }

        public static string GetProductCurrencyIcon(string productId)
        {
            var product = RocGMPurchaseController.Instance.GetProductWithId(productId);

            if (product == null) return FallbackCurrencyIcon;

            var code = product.metadata.isoCurrencyCode;
            if (string.IsNullOrEmpty(code))
            {
                return FallbackCurrencyIcon;
            }

            return TryGetCurrencyIcon(code, out var icon) ? icon : code;
        }
    }
}